# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: terachem_server.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="terachem_server.proto",
    package="terachem_server",
    syntax="proto3",
    serialized_options=b"\252\002\030Google.Protobuf.TeraChem",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x15terachem_server.proto\x12\x0fterachem_server"\x9d\x01\n\x06Status\x12\x0c\n\x04\x62usy\x18\x01 \x01(\x08\x12\x12\n\x08\x61\x63\x63\x65pted\x18\x02 \x01(\x08H\x00\x12\x11\n\x07working\x18\x03 \x01(\x08H\x00\x12\x13\n\tcompleted\x18\x04 \x01(\x08H\x00\x12\x0f\n\x07job_dir\x18\x05 \x01(\t\x12\x13\n\x0bjob_scr_dir\x18\x06 \x01(\t\x12\x15\n\rserver_job_id\x18\x07 \x01(\x05\x42\x0c\n\njob_status"\xbd\x01\n\x03Mol\x12\r\n\x05\x61toms\x18\x01 \x03(\t\x12\x0b\n\x03xyz\x18\x02 \x03(\x01\x12,\n\x05units\x18\x03 \x01(\x0e\x32\x1d.terachem_server.Mol.UnitType\x12\x0e\n\x06\x63harge\x18\x04 \x01(\x05\x12\x14\n\x0cmultiplicity\x18\x05 \x01(\x05\x12\x0e\n\x06\x63losed\x18\x06 \x01(\x08\x12\x12\n\nrestricted\x18\x07 \x01(\x08""\n\x08UnitType\x12\x0c\n\x08\x41NGSTROM\x10\x00\x12\x08\n\x04\x42OHR\x10\x01"\xf4\t\n\x08JobInput\x12!\n\x03mol\x18\x01 \x01(\x0b\x32\x14.terachem_server.Mol\x12.\n\x03run\x18\x02 \x01(\x0e\x32!.terachem_server.JobInput.RunType\x12\x34\n\x06method\x18\x03 \x01(\x0e\x32$.terachem_server.JobInput.MethodType\x12\r\n\x05\x62\x61sis\x18\x04 \x01(\t\x12\x14\n\x0cuser_options\x18\x07 \x03(\t\x12\x11\n\torb1afile\x18\x08 \x01(\t\x12\x11\n\torb1bfile\x18\t \x01(\t\x12\x19\n\x11return_bond_order\x18\x10 \x01(\x08\x12\x0c\n\x04xyz2\x18\x11 \x03(\x01\x12\x33\n\x08imd_type\x18\x14 \x01(\x0e\x32!.terachem_server.JobInput.ImdType\x12\x1b\n\x13imd_initial_orbital\x18\x15 \x01(\x05\x12\x42\n\x10imd_orbital_type\x18\x1b \x01(\x0e\x32(.terachem_server.JobInput.ImdOrbitalType\x12\x18\n\x10imd_xyz_previous\x18\x16 \x03(\x01\x12\x17\n\x0fimd_mo_previous\x18\x17 \x03(\x02\x12\x1b\n\x13imd_mmatom_position\x18\x18 \x03(\x02\x12\x17\n\x0fimd_mmatom_info\x18\x19 \x03(\x02\x12L\n\x15imd_additional_option\x18\x1a \x01(\x0e\x32-.terachem_server.JobInput.ImdAdditionalOption"O\n\x07RunType\x12\n\n\x06\x45NERGY\x10\x00\x12\x0c\n\x08GRADIENT\x10\x01\x12\x0c\n\x08\x43OUPLING\x10\x0e\x12\x08\n\x04TDCI\x10\x10\x12\x12\n\x0e\x43I_VEC_OVERLAP\x10\x13"\xbc\x02\n\nMethodType\x12\x06\n\x02HF\x10\x00\x12\x08\n\x04\x43\x41SE\x10\x02\x12\t\n\x05SVWN1\x10\x03\x12\t\n\x05SVWN3\x10\x04\x12\t\n\x05SVWN5\x10\x05\x12\x08\n\x04SVWN\x10\x05\x12\n\n\x06\x42\x33LYP1\x10\x06\x12\t\n\x05\x42\x33LYP\x10\x06\x12\n\n\x06\x42\x33LYP3\x10\x07\x12\n\n\x06\x42\x33LYP5\x10\x08\x12\x08\n\x04\x42LYP\x10\t\x12\r\n\tBHANDHLYP\x10\n\x12\x07\n\x03PBE\x10\x0b\x12\n\n\x06REVPBE\x10\x0c\x12\x08\n\x04PBE0\x10\r\x12\x0b\n\x07REVPBE0\x10\x0e\x12\x08\n\x04WPBE\x10\x0f\x12\t\n\x05WPBEH\x10\x10\x12\x07\n\x03\x42OP\x10\x11\x12\t\n\x05MUBOP\x10\x12\x12\x0c\n\x08\x43\x41MB3LYP\x10\x13\x12\x07\n\x03\x42\x39\x37\x10\x14\x12\x08\n\x04WB97\x10\x15\x12\t\n\x05WB97X\x10\x16\x12\x0b\n\x07WB97XD3\x10\x17\x12\n\n\x06GFNXTB\x10\x18\x12\x0b\n\x07GFN2XTB\x10\x19\x1a\x02\x10\x01"P\n\x07ImdType\x12\x0b\n\x07NOT_IMD\x10\x00\x12\x15\n\x11IMD_NEW_CONDITION\x10\x01\x12\x10\n\x0cIMD_CONTINUE\x10\x02\x12\x0f\n\x0bIMD_HESSIAN\x10\x03"w\n\x0eImdOrbitalType\x12\x0e\n\nNO_ORBITAL\x10\x00\x12\x11\n\rALPHA_ORBITAL\x10\x01\x12\x10\n\x0c\x42\x45TA_ORBITAL\x10\x02\x12\x11\n\rALPHA_DENSITY\x10\x03\x12\x10\n\x0c\x42\x45TA_DENSITY\x10\x04\x12\x0b\n\x07WHOLE_C\x10\x05"C\n\x13ImdAdditionalOption\x12\x11\n\rIMD_NORMAL_MD\x10\x00\x12\x19\n\x15IMD_MECI_OPT_GRADIENT\x10\x01"\xc8\x06\n\tJobOutput\x12!\n\x03mol\x18\x01 \x01(\x0b\x32\x14.terachem_server.Mol\x12\x0e\n\x06\x65nergy\x18\x02 \x03(\x01\x12\x10\n\x08gradient\x18\x03 \x03(\x01\x12\x0f\n\x07\x63harges\x18\x04 \x03(\x01\x12\r\n\x05spins\x18\x05 \x03(\x01\x12\x0f\n\x07\x64ipoles\x18\x06 \x03(\x01\x12\x0f\n\x07job_dir\x18\t \x01(\t\x12\x13\n\x0bjob_scr_dir\x18\n \x01(\t\x12\x15\n\rserver_job_id\x18\x0b \x01(\x05\x12\x11\n\torb1afile\x18\x0c \x01(\t\x12\x11\n\torb1bfile\x18\r \x01(\t\x12\x10\n\x08orb_size\x18\x0e \x01(\x05\x12\x12\n\nbond_order\x18\x10 \x03(\x01\x12\x13\n\x0b\x63i_overlaps\x18\x11 \x03(\x01\x12\x17\n\x0f\x63i_overlap_size\x18\x12 \x01(\x05\x12\x19\n\x11\x63\x61s_energy_states\x18\x13 \x03(\x05\x12\x18\n\x10\x63\x61s_energy_mults\x18\x14 \x03(\x05\x12\x1d\n\x15\x63\x61s_transition_dipole\x18\x16 \x03(\x01\x12\r\n\x05nacme\x18\x15 \x03(\x01\x12\x15\n\rorba_energies\x18\x19 \x03(\x01\x12\x15\n\rorbb_energies\x18\x1a \x03(\x01\x12\x18\n\x10orba_occupations\x18\x1b \x03(\x01\x12\x18\n\x10orbb_occupations\x18\x1c \x03(\x01\x12\x12\n\ncis_states\x18\x1d \x01(\x05\x12\x1d\n\x15\x63is_unrelaxed_dipoles\x18\x1e \x03(\x01\x12\x1b\n\x13\x63is_relaxed_dipoles\x18\x1f \x03(\x01\x12\x1e\n\x16\x63is_transition_dipoles\x18  \x03(\x01\x12\x11\n\tci_vec_re\x18! \x03(\x01\x12\x11\n\tci_vec_im\x18" \x03(\x01\x12\x1d\n\x15\x63ompressed_bond_order\x18# \x03(\r\x12\x1a\n\x12\x63ompressed_hessian\x18$ \x03(\x02\x12\x1a\n\x12\x63ompressed_ao_data\x18% \x03(\x02\x12!\n\x19\x63ompressed_primitive_data\x18& \x03(\x02\x12\x1c\n\x14\x63ompressed_mo_vector\x18\' \x03(\x02\x12\x1b\n\x13imd_mmatom_gradient\x18( \x03(\x02*?\n\x0bMessageType\x12\n\n\x06STATUS\x10\x00\x12\x07\n\x03MOL\x10\x01\x12\x0c\n\x08JOBINPUT\x10\x02\x12\r\n\tJOBOUTPUT\x10\x03\x42\x1b\xaa\x02\x18Google.Protobuf.TeraChemb\x06proto3',
)

_MESSAGETYPE = _descriptor.EnumDescriptor(
    name="MessageType",
    full_name="terachem_server.MessageType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="STATUS",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="MOL",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="JOBINPUT",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="JOBOUTPUT",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2508,
    serialized_end=2571,
)
_sym_db.RegisterEnumDescriptor(_MESSAGETYPE)

MessageType = enum_type_wrapper.EnumTypeWrapper(_MESSAGETYPE)
STATUS = 0
MOL = 1
JOBINPUT = 2
JOBOUTPUT = 3


_MOL_UNITTYPE = _descriptor.EnumDescriptor(
    name="UnitType",
    full_name="terachem_server.Mol.UnitType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ANGSTROM",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BOHR",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=358,
    serialized_end=392,
)
_sym_db.RegisterEnumDescriptor(_MOL_UNITTYPE)

_JOBINPUT_RUNTYPE = _descriptor.EnumDescriptor(
    name="RunType",
    full_name="terachem_server.JobInput.RunType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ENERGY",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="GRADIENT",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="COUPLING",
            index=2,
            number=14,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TDCI",
            index=3,
            number=16,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CI_VEC_OVERLAP",
            index=4,
            number=19,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=993,
    serialized_end=1072,
)
_sym_db.RegisterEnumDescriptor(_JOBINPUT_RUNTYPE)

_JOBINPUT_METHODTYPE = _descriptor.EnumDescriptor(
    name="MethodType",
    full_name="terachem_server.JobInput.MethodType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="HF",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CASE",
            index=1,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SVWN1",
            index=2,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SVWN3",
            index=3,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SVWN5",
            index=4,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SVWN",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="B3LYP1",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="B3LYP",
            index=7,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="B3LYP3",
            index=8,
            number=7,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="B3LYP5",
            index=9,
            number=8,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BLYP",
            index=10,
            number=9,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BHANDHLYP",
            index=11,
            number=10,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PBE",
            index=12,
            number=11,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="REVPBE",
            index=13,
            number=12,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PBE0",
            index=14,
            number=13,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="REVPBE0",
            index=15,
            number=14,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WPBE",
            index=16,
            number=15,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WPBEH",
            index=17,
            number=16,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BOP",
            index=18,
            number=17,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="MUBOP",
            index=19,
            number=18,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CAMB3LYP",
            index=20,
            number=19,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="B97",
            index=21,
            number=20,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WB97",
            index=22,
            number=21,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WB97X",
            index=23,
            number=22,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WB97XD3",
            index=24,
            number=23,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="GFNXTB",
            index=25,
            number=24,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="GFN2XTB",
            index=26,
            number=25,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=b"\020\001",
    serialized_start=1075,
    serialized_end=1391,
)
_sym_db.RegisterEnumDescriptor(_JOBINPUT_METHODTYPE)

_JOBINPUT_IMDTYPE = _descriptor.EnumDescriptor(
    name="ImdType",
    full_name="terachem_server.JobInput.ImdType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="NOT_IMD",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IMD_NEW_CONDITION",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IMD_CONTINUE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IMD_HESSIAN",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1393,
    serialized_end=1473,
)
_sym_db.RegisterEnumDescriptor(_JOBINPUT_IMDTYPE)

_JOBINPUT_IMDORBITALTYPE = _descriptor.EnumDescriptor(
    name="ImdOrbitalType",
    full_name="terachem_server.JobInput.ImdOrbitalType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="NO_ORBITAL",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ALPHA_ORBITAL",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BETA_ORBITAL",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ALPHA_DENSITY",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BETA_DENSITY",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WHOLE_C",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1475,
    serialized_end=1594,
)
_sym_db.RegisterEnumDescriptor(_JOBINPUT_IMDORBITALTYPE)

_JOBINPUT_IMDADDITIONALOPTION = _descriptor.EnumDescriptor(
    name="ImdAdditionalOption",
    full_name="terachem_server.JobInput.ImdAdditionalOption",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="IMD_NORMAL_MD",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IMD_MECI_OPT_GRADIENT",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1596,
    serialized_end=1663,
)
_sym_db.RegisterEnumDescriptor(_JOBINPUT_IMDADDITIONALOPTION)


_STATUS = _descriptor.Descriptor(
    name="Status",
    full_name="terachem_server.Status",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="busy",
            full_name="terachem_server.Status.busy",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="accepted",
            full_name="terachem_server.Status.accepted",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="working",
            full_name="terachem_server.Status.working",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="completed",
            full_name="terachem_server.Status.completed",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="job_dir",
            full_name="terachem_server.Status.job_dir",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="job_scr_dir",
            full_name="terachem_server.Status.job_scr_dir",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="server_job_id",
            full_name="terachem_server.Status.server_job_id",
            index=6,
            number=7,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="job_status",
            full_name="terachem_server.Status.job_status",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=43,
    serialized_end=200,
)


_MOL = _descriptor.Descriptor(
    name="Mol",
    full_name="terachem_server.Mol",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="atoms",
            full_name="terachem_server.Mol.atoms",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="xyz",
            full_name="terachem_server.Mol.xyz",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="units",
            full_name="terachem_server.Mol.units",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="charge",
            full_name="terachem_server.Mol.charge",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="multiplicity",
            full_name="terachem_server.Mol.multiplicity",
            index=4,
            number=5,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="closed",
            full_name="terachem_server.Mol.closed",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="restricted",
            full_name="terachem_server.Mol.restricted",
            index=6,
            number=7,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _MOL_UNITTYPE,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=203,
    serialized_end=392,
)


_JOBINPUT = _descriptor.Descriptor(
    name="JobInput",
    full_name="terachem_server.JobInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="mol",
            full_name="terachem_server.JobInput.mol",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="run",
            full_name="terachem_server.JobInput.run",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="method",
            full_name="terachem_server.JobInput.method",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="basis",
            full_name="terachem_server.JobInput.basis",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="user_options",
            full_name="terachem_server.JobInput.user_options",
            index=4,
            number=7,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="orb1afile",
            full_name="terachem_server.JobInput.orb1afile",
            index=5,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="orb1bfile",
            full_name="terachem_server.JobInput.orb1bfile",
            index=6,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="return_bond_order",
            full_name="terachem_server.JobInput.return_bond_order",
            index=7,
            number=16,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="xyz2",
            full_name="terachem_server.JobInput.xyz2",
            index=8,
            number=17,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imd_type",
            full_name="terachem_server.JobInput.imd_type",
            index=9,
            number=20,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imd_initial_orbital",
            full_name="terachem_server.JobInput.imd_initial_orbital",
            index=10,
            number=21,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imd_orbital_type",
            full_name="terachem_server.JobInput.imd_orbital_type",
            index=11,
            number=27,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imd_xyz_previous",
            full_name="terachem_server.JobInput.imd_xyz_previous",
            index=12,
            number=22,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imd_mo_previous",
            full_name="terachem_server.JobInput.imd_mo_previous",
            index=13,
            number=23,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imd_mmatom_position",
            full_name="terachem_server.JobInput.imd_mmatom_position",
            index=14,
            number=24,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imd_mmatom_info",
            full_name="terachem_server.JobInput.imd_mmatom_info",
            index=15,
            number=25,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imd_additional_option",
            full_name="terachem_server.JobInput.imd_additional_option",
            index=16,
            number=26,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _JOBINPUT_RUNTYPE,
        _JOBINPUT_METHODTYPE,
        _JOBINPUT_IMDTYPE,
        _JOBINPUT_IMDORBITALTYPE,
        _JOBINPUT_IMDADDITIONALOPTION,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=395,
    serialized_end=1663,
)


_JOBOUTPUT = _descriptor.Descriptor(
    name="JobOutput",
    full_name="terachem_server.JobOutput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="mol",
            full_name="terachem_server.JobOutput.mol",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="energy",
            full_name="terachem_server.JobOutput.energy",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gradient",
            full_name="terachem_server.JobOutput.gradient",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="charges",
            full_name="terachem_server.JobOutput.charges",
            index=3,
            number=4,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="spins",
            full_name="terachem_server.JobOutput.spins",
            index=4,
            number=5,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dipoles",
            full_name="terachem_server.JobOutput.dipoles",
            index=5,
            number=6,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="job_dir",
            full_name="terachem_server.JobOutput.job_dir",
            index=6,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="job_scr_dir",
            full_name="terachem_server.JobOutput.job_scr_dir",
            index=7,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="server_job_id",
            full_name="terachem_server.JobOutput.server_job_id",
            index=8,
            number=11,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="orb1afile",
            full_name="terachem_server.JobOutput.orb1afile",
            index=9,
            number=12,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="orb1bfile",
            full_name="terachem_server.JobOutput.orb1bfile",
            index=10,
            number=13,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="orb_size",
            full_name="terachem_server.JobOutput.orb_size",
            index=11,
            number=14,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="bond_order",
            full_name="terachem_server.JobOutput.bond_order",
            index=12,
            number=16,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ci_overlaps",
            full_name="terachem_server.JobOutput.ci_overlaps",
            index=13,
            number=17,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ci_overlap_size",
            full_name="terachem_server.JobOutput.ci_overlap_size",
            index=14,
            number=18,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="cas_energy_states",
            full_name="terachem_server.JobOutput.cas_energy_states",
            index=15,
            number=19,
            type=5,
            cpp_type=1,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="cas_energy_mults",
            full_name="terachem_server.JobOutput.cas_energy_mults",
            index=16,
            number=20,
            type=5,
            cpp_type=1,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="cas_transition_dipole",
            full_name="terachem_server.JobOutput.cas_transition_dipole",
            index=17,
            number=22,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="nacme",
            full_name="terachem_server.JobOutput.nacme",
            index=18,
            number=21,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="orba_energies",
            full_name="terachem_server.JobOutput.orba_energies",
            index=19,
            number=25,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="orbb_energies",
            full_name="terachem_server.JobOutput.orbb_energies",
            index=20,
            number=26,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="orba_occupations",
            full_name="terachem_server.JobOutput.orba_occupations",
            index=21,
            number=27,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="orbb_occupations",
            full_name="terachem_server.JobOutput.orbb_occupations",
            index=22,
            number=28,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="cis_states",
            full_name="terachem_server.JobOutput.cis_states",
            index=23,
            number=29,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="cis_unrelaxed_dipoles",
            full_name="terachem_server.JobOutput.cis_unrelaxed_dipoles",
            index=24,
            number=30,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="cis_relaxed_dipoles",
            full_name="terachem_server.JobOutput.cis_relaxed_dipoles",
            index=25,
            number=31,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="cis_transition_dipoles",
            full_name="terachem_server.JobOutput.cis_transition_dipoles",
            index=26,
            number=32,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ci_vec_re",
            full_name="terachem_server.JobOutput.ci_vec_re",
            index=27,
            number=33,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ci_vec_im",
            full_name="terachem_server.JobOutput.ci_vec_im",
            index=28,
            number=34,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="compressed_bond_order",
            full_name="terachem_server.JobOutput.compressed_bond_order",
            index=29,
            number=35,
            type=13,
            cpp_type=3,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="compressed_hessian",
            full_name="terachem_server.JobOutput.compressed_hessian",
            index=30,
            number=36,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="compressed_ao_data",
            full_name="terachem_server.JobOutput.compressed_ao_data",
            index=31,
            number=37,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="compressed_primitive_data",
            full_name="terachem_server.JobOutput.compressed_primitive_data",
            index=32,
            number=38,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="compressed_mo_vector",
            full_name="terachem_server.JobOutput.compressed_mo_vector",
            index=33,
            number=39,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imd_mmatom_gradient",
            full_name="terachem_server.JobOutput.imd_mmatom_gradient",
            index=34,
            number=40,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1666,
    serialized_end=2506,
)

_STATUS.oneofs_by_name["job_status"].fields.append(_STATUS.fields_by_name["accepted"])
_STATUS.fields_by_name["accepted"].containing_oneof = _STATUS.oneofs_by_name[
    "job_status"
]
_STATUS.oneofs_by_name["job_status"].fields.append(_STATUS.fields_by_name["working"])
_STATUS.fields_by_name["working"].containing_oneof = _STATUS.oneofs_by_name[
    "job_status"
]
_STATUS.oneofs_by_name["job_status"].fields.append(_STATUS.fields_by_name["completed"])
_STATUS.fields_by_name["completed"].containing_oneof = _STATUS.oneofs_by_name[
    "job_status"
]
_MOL.fields_by_name["units"].enum_type = _MOL_UNITTYPE
_MOL_UNITTYPE.containing_type = _MOL
_JOBINPUT.fields_by_name["mol"].message_type = _MOL
_JOBINPUT.fields_by_name["run"].enum_type = _JOBINPUT_RUNTYPE
_JOBINPUT.fields_by_name["method"].enum_type = _JOBINPUT_METHODTYPE
_JOBINPUT.fields_by_name["imd_type"].enum_type = _JOBINPUT_IMDTYPE
_JOBINPUT.fields_by_name["imd_orbital_type"].enum_type = _JOBINPUT_IMDORBITALTYPE
_JOBINPUT.fields_by_name[
    "imd_additional_option"
].enum_type = _JOBINPUT_IMDADDITIONALOPTION
_JOBINPUT_RUNTYPE.containing_type = _JOBINPUT
_JOBINPUT_METHODTYPE.containing_type = _JOBINPUT
_JOBINPUT_IMDTYPE.containing_type = _JOBINPUT
_JOBINPUT_IMDORBITALTYPE.containing_type = _JOBINPUT
_JOBINPUT_IMDADDITIONALOPTION.containing_type = _JOBINPUT
_JOBOUTPUT.fields_by_name["mol"].message_type = _MOL
DESCRIPTOR.message_types_by_name["Status"] = _STATUS
DESCRIPTOR.message_types_by_name["Mol"] = _MOL
DESCRIPTOR.message_types_by_name["JobInput"] = _JOBINPUT
DESCRIPTOR.message_types_by_name["JobOutput"] = _JOBOUTPUT
DESCRIPTOR.enum_types_by_name["MessageType"] = _MESSAGETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Status = _reflection.GeneratedProtocolMessageType(
    "Status",
    (_message.Message,),
    {
        "DESCRIPTOR": _STATUS,
        "__module__": "terachem_server_pb2"
        # @@protoc_insertion_point(class_scope:terachem_server.Status)
    },
)
_sym_db.RegisterMessage(Status)

Mol = _reflection.GeneratedProtocolMessageType(
    "Mol",
    (_message.Message,),
    {
        "DESCRIPTOR": _MOL,
        "__module__": "terachem_server_pb2"
        # @@protoc_insertion_point(class_scope:terachem_server.Mol)
    },
)
_sym_db.RegisterMessage(Mol)

JobInput = _reflection.GeneratedProtocolMessageType(
    "JobInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _JOBINPUT,
        "__module__": "terachem_server_pb2"
        # @@protoc_insertion_point(class_scope:terachem_server.JobInput)
    },
)
_sym_db.RegisterMessage(JobInput)

JobOutput = _reflection.GeneratedProtocolMessageType(
    "JobOutput",
    (_message.Message,),
    {
        "DESCRIPTOR": _JOBOUTPUT,
        "__module__": "terachem_server_pb2"
        # @@protoc_insertion_point(class_scope:terachem_server.JobOutput)
    },
)
_sym_db.RegisterMessage(JobOutput)


DESCRIPTOR._options = None
_JOBINPUT_METHODTYPE._options = None
# @@protoc_insertion_point(module_scope)
